<?php
/**
 *
 * Description
 *
 * @package    VirtueMart
 * @subpackage
 * @author Nanda K
 * @version $Id: qb.php 2017-28-06 
 */

// Check to ensure this file is included in Joomla!
defined ('_JEXEC') or die('Restricted access');

if (!class_exists ('VmModel')) {
	require(VMPATH_ADMIN . DS . 'helpers' . DS . 'vmmodel.php');
}

/**
 * Model for VirtueMart Vendors
 *
 * @package        VirtueMart
 */
class VirtueMartModelQB extends VmModel {

	/**
	 * constructs a VmModel
	 * setMainTable defines the maintable of the model
	 *
	 * @author Max Milbers
	 */
	function __construct () {

		parent::__construct ();

		$this->setMainTable ('qb');
	}


	/**
	 * Retrieve the QB details from the database.
	 *
	 * @author Nanda
	 * @return object QB details
	 */
	function getQBDetails ($id = 0) {

		if(!empty($id)) $this->_id = (int)$id;

		if (empty($this->_cache[$this->_id][VmConfig::$vmlang])) {

			$this->_cache[$this->_id][VmConfig::$vmlang] = $this->getTable ('qb');
			$this->_cache[$this->_id][VmConfig::$vmlang]->load ($this->_id);
// 			vmdebug('getVendor',$this->_id,$this->_data);
		}

		return $this->_cache[$this->_id][VmConfig::$vmlang];
	}

	/**
	 * Retrieve a list of QBs
	 * @author Nanda
	 * @return object List of QBs
	 */
	public function getQBs () {

		$this->setId (0); //This is important ! notice by Max Milbers
		$query = 'SELECT * FROM `#__virtuemart_qb` as q ';
		$query .= ' ORDER BY q.`id`';
		$this->_data = $this->_getList ($query, $this->getState ('limitstart'), $this->getState ('limit'));
		return $this->_data;
	}

	public function getQBNames () {
		static $qbNames=0;
		if(empty($qbNames)){
			$q = 'SELECT `qbname`,`id` as `virtuemart_qb_id` FROM `#__virtuemart_qb` order by `id` ';
			$db = JFactory::getDBO();
			$db->setQuery($q);
			$qbNames = $db->loadAssocList('virtuemart_qb_id');
		}

		return $qbNames;

	}
	
	function renderQBList($value,$name = 'qbname',$multiple=FALSE,$attrs='',$langkey=''){

		$idA = $id = $name;
 		$attrs .= ' class="inputbox" ';
		if ($multiple) {
			$attrs .= ' multiple="multiple" ';
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_DRDOWN_SELECT_SOME_OPTIONS';
			$attrs .=  ' data-placeholder="'.vmText::_($langkey).'"';
			$idA .= '[]';
		} else {
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_LIST_EMPTY_OPTION';
		}

		if (!isset($this->_renderQBList)) {
			$qbNames = $this->getQBNames();
			$emptyOption = JHtml::_ ('select.option', -1, vmText::_ ($langkey), 'virtuemart_qb_id', 'qbname');
			array_unshift ($qbNames, $emptyOption);
			if ($multiple) {
				$attrs .=' size="'.count($qbNames).'" ';
			}

			$this->_renderQBList = JHtml::_('select.genericlist', $qbNames, $idA, $attrs, 'virtuemart_qb_id', 'qbname', $value,$id,true);
		}
		return $this->_renderQBList ;
	}	
	
	function renderQB2List($value,$name = 'qbname',$multiple=FALSE,$attrs='',$langkey=''){

		$idA = $id = $name;
 		$attrs .= ' class="inputbox" ';
		if ($multiple) {
			$attrs .= ' multiple="multiple" ';
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_DRDOWN_SELECT_SOME_OPTIONS';
			$attrs .=  ' data-placeholder="'.vmText::_($langkey).'"';
			$idA .= '[]';
		} else {
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_LIST_EMPTY_OPTION';
		}

		if (!isset($this->_renderQB2List)) {
			$qbNames = $this->getQBNames();
			$emptyOption = JHtml::_ ('select.option', -1, vmText::_ ($langkey), 'virtuemart_qb_id', 'qbname');
			array_unshift ($qbNames, $emptyOption);
			if ($multiple) {
				$attrs .=' size="'.count($qbNames).'" ';
			}

			$this->_renderQB2List = JHtml::_('select.genericlist', $qbNames, $idA, $attrs, 'virtuemart_qb_id', 'qbname', $value,$id,true);
		}
		return $this->_renderQB2List ;
	}		

	function renderQB3List($value,$name = 'qbname',$multiple=FALSE,$attrs='',$langkey=''){

		$idA = $id = $name;
 		$attrs .= ' class="inputbox" ';
		if ($multiple) {
			$attrs .= ' multiple="multiple" ';
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_DRDOWN_SELECT_SOME_OPTIONS';
			$attrs .=  ' data-placeholder="'.vmText::_($langkey).'"';
			$idA .= '[]';
		} else {
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_LIST_EMPTY_OPTION';
		}

		if (!isset($this->_renderQB3List)) {
			$qbNames = $this->getQBNames();
			$emptyOption = JHtml::_ ('select.option', -1, vmText::_ ($langkey), 'virtuemart_qb_id', 'qbname');
			array_unshift ($qbNames, $emptyOption);
			if ($multiple) {
				$attrs .=' size="'.count($qbNames).'" ';
			}

			$this->_renderQB3List = JHtml::_('select.genericlist', $qbNames, $idA, $attrs, 'virtuemart_qb_id', 'qbname', $value,$id,true);
		}
		return $this->_renderQB3List ;
	}
	
	/**
	 * Bind the post data to the QB table and save it
	 *
	 * @author Nanda
	 * @return boolean True is the save was successful, false otherwise.
	 */
	function store (&$data) {

		$dispatcher = JDispatcher::getInstance ();

		$oldVendorId = $data['id'];

		$table = $this->getTable ('qb');

		if(empty($data['qbname'])){
			if(!empty($data['title'])){
				$data['qbname'] = '';
				$data['qbname'] = $data['title'].' ';
			}
			if(!empty($data['qty'])){
				$data['quantity'] .= $data['qty'];
			}
		}


		$res = $table->bindChecknStore ($data);
		if(!$res) {
			vmError ('Error storing vendor');
		}

		//set vendormodel id to the lastinserted one
		if (empty($this->_id)) {
			$data['id'] = $this->_id = $table->id;
		} else {
			$data['id'] = $table->id;
		}
		return $this->_id;

	}

}
