<?php
/**
 *
 * Description
 *
 * @package    VirtueMart
 * @subpackage
 * @author Nanda K
 * @version $Id: salteitem.php 2017-04-07 
 */

// Check to ensure this file is included in Joomla!
defined ('_JEXEC') or die('Restricted access');

if (!class_exists ('VmModel')) {
	require(VMPATH_ADMIN . DS . 'helpers' . DS . 'vmmodel.php');
}

/**
 * Model for VirtueMart SaleItem
 *
 * @package        VirtueMart
 */
class VirtueMartModelSaleItem extends VmModel {

	/**
	 * constructs a VmModel
	 * setMainTable defines the maintable of the model
	 *
	 * @author Max Milbers
	 */
	function __construct () {

		parent::__construct ();

		$this->setMainTable ('saleitem');
	}

	/**
	 * Return the saleitem names
	 *
	 * @author Nanda Kishore
	 * @access public
	 *
	 * @param char $id saleitem id
	 * @return string The name of the saleitem
	 */
	public function getSaleItemNames () {
		static $saleItemNames=0;
		if(empty($saleItemNames)){
			$q = 'SELECT `saleitemname`,`virtuemart_saleitem_id` FROM `#__virtuemart_saleitem` order by `virtuemart_saleitem_id` ';
			$db = JFactory::getDBO();
			$db->setQuery($q);
			$saleItemNames = $db->loadAssocList('virtuemart_saleitem_id');
		}

		return $saleItemNames;

	}
	
	function renderSIList($value,$name = 'saleitemname',$multiple=FALSE,$attrs='',$langkey=''){

		$idA = $id = $name;
 		$attrs .= ' class="inputbox" ';
		if ($multiple) {
			$attrs .= ' multiple="multiple" ';
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_DRDOWN_SELECT_SOME_OPTIONS';
			$attrs .=  ' data-placeholder="'.vmText::_($langkey).'"';
			$idA .= '[]';
		} else {
			if(empty($langkey)) $langkey = 'COM_VIRTUEMART_LIST_EMPTY_OPTION';
		}

		if (!isset($this->_renderSIList)) {
			$saleItemNames = $this->getSaleItemNames();
			//print_r($saleItemNames);
			$emptyOption = JHtml::_ ('select.option', -1, vmText::_ ($langkey), 'virtuemart_saleitem_id', 'saleitemname');
			array_unshift ($saleItemNames, $emptyOption);
			if ($multiple) {
				$attrs .=' size="'.count($saleItemNames).'" ';
			}

			$this->_renderSIList = JHtml::_('select.genericlist', $saleItemNames, $idA, $attrs, 'virtuemart_saleitem_id', 'saleitemname', $value,$id,true);
		}
		//print_r($this->_renderSIList);
		return $this->_renderSIList ;
	}	
	
	/**
	 * Retrieve the SaleItem details from the database.
	 *
	 * @author Nanda
	 * @return object SaleItem details
	 */
	function getSaleItemDetails ($id = 0) {

		if(!empty($id)) $this->_virtuemart_saleitem_id = (int)$id;

		if (empty($this->_cache[$this->_virtuemart_saleitem_id][VmConfig::$vmlang])) {

			$this->_cache[$this->_virtuemart_saleitem_id][VmConfig::$vmlang] = $this->getTable ('saleitem');
			$this->_cache[$this->_virtuemart_saleitem_id][VmConfig::$vmlang]->load ($this->_virtuemart_saleitem_id);
		}

		return $this->_cache[$this->_virtuemart_saleitem_id][VmConfig::$vmlang];
	}

	/**
	 * Retrieve a list of QBs
	 * @author Nanda
	 * @return object List of QBs
	 */
	public function getSaleItems () {

		$this->setId (0); //This is important ! notice by Max Milbers
		$query = 'SELECT * FROM `#__virtuemart_saleitem` as q ';
		$query .= ' ORDER BY q.`virtuemart_saleitem_id`';
		$this->_data = $this->_getList ($query, $this->getState ('limitstart'), $this->getState ('limit'));
		return $this->_data;
	}


	/**
	 * Bind the post data to the QB table and save it
	 *
	 * @author Nanda
	 * @return boolean True is the save was successful, false otherwise.
	 */
	function store (&$data) {

		$dispatcher = JDispatcher::getInstance ();

		$table = $this->getTable ('saleitem');

		if(empty($data['saleitemname'])){
			if(!empty($data['title'])){
				$data['saleitemname'] = '';
				$data['saleitemname'] = $data['title'].' ';
			}
			if(!empty($data['qty'])){
				$data['quantity'] .= $data['qty'];
			}
		}
		//print_r($data);
		$res = $table->bindChecknStore ($data);
		if(!$res) {
			vmError ('Error storing vendor');
		}

		//set vendormodel id to the lastinserted one
		if (empty($this->_virtuemart_saleitem_id)) {
			$data['virtuemart_saleitem_id'] = $this->_virtuemart_saleitem_id = $table->virtuemart_saleitem_id;
		} else {
			$data['virtuemart_saleitem_id'] = $table->virtuemart_saleitem_id;
		}
		return $this->_virtuemart_saleitem_id;

	}

}
